==> vtk6-6.3.0-4-aarch64.pkg.tar.xz: vtk/vtkObject.java <==
// java wrapper for vtkObject object
//

package vtk;
import vtk.*;

public class vtkObject extends vtkObjectBase
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DebugOn_2();
  public void DebugOn()
    { DebugOn_2(); }

  private native void DebugOff_3();
  public void DebugOff()
    { DebugOff_3(); }

  private native boolean GetDebug_4();
  public boolean GetDebug()
    { return GetDebug_4(); }

  private native void SetDebug_5(boolean id0);
  public void SetDebug(boolean id0)
    { SetDebug_5(id0); }

  private native void BreakOnError_6();
  public void BreakOnError()
    { BreakOnError_6(); }

  private native void Modified_7();
  public void Modified()
    { Modified_7(); }

  private native int GetMTime_8();
  public int GetMTime()
    { return GetMTime_8(); }

  private native void SetGlobalWarningDisplay_9(int id0);
  public void SetGlobalWarningDisplay(int id0)
    { SetGlobalWarningDisplay_9(id0); }

  private native void GlobalWarningDisplayOn_10();
  public void GlobalWarningDisplayOn()
    { GlobalWarningDisplayOn_10(); }

  private native void GlobalWarningDisplayOff_11();
  public void GlobalWarningDisplayOff()
    { GlobalWarningDisplayOff_11(); }

  private native int GetGlobalWarningDisplay_12();
  public int GetGlobalWarningDisplay()
    { return GetGlobalWarningDisplay_12(); }

  private native void RemoveObserver_13(int id0);
  public void RemoveObserver(int id0)
    { RemoveObserver_13(id0); }

  private native void RemoveObservers_14(int id0);
  public void RemoveObservers(int id0)
    { RemoveObservers_14(id0); }

  private native void RemoveObservers_15(String id0);
  public void RemoveObservers(String id0)
    { RemoveObservers_15(id0); }

  private native void RemoveAllObservers_16();
  public void RemoveAllObservers()
    { RemoveAllObservers_16(); }

  private native int HasObserver_17(int id0);
  public int HasObserver(int id0)
    { return HasObserver_17(id0); }

  private native int HasObserver_18(String id0);
  public int HasObserver(String id0)
    { return HasObserver_18(id0); }

  private native int InvokeEvent_19(int id0);
  public int InvokeEvent(int id0)
    { return InvokeEvent_19(id0); }

  private native int InvokeEvent_20(String id0);
  public int InvokeEvent(String id0)
    { return InvokeEvent_20(id0); }

  public vtkObject() { super(); }

  public vtkObject(long id) { super(id); }
  public native long   VTKInit();
  public native int AddObserver(String id0, Object id1, String id2);

}

==> vtk-8.2.0-19-aarch64.pkg.tar.xz: vtk/vtkObject.java <==
// java wrapper for vtkObject object
//

package vtk;
import vtk.*;

public class vtkObject extends vtkObjectBase
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DebugOn_2();
  public void DebugOn()
    { DebugOn_2(); }

  private native void DebugOff_3();
  public void DebugOff()
    { DebugOff_3(); }

  private native boolean GetDebug_4();
  public boolean GetDebug()
    { return GetDebug_4(); }

  private native void SetDebug_5(boolean id0);
  public void SetDebug(boolean id0)
    { SetDebug_5(id0); }

  private native void BreakOnError_6();
  public void BreakOnError()
    { BreakOnError_6(); }

  private native void Modified_7();
  public void Modified()
    { Modified_7(); }

  private native int GetMTime_8();
  public int GetMTime()
    { return GetMTime_8(); }

  private native void SetGlobalWarningDisplay_9(int id0);
  public void SetGlobalWarningDisplay(int id0)
    { SetGlobalWarningDisplay_9(id0); }

  private native void GlobalWarningDisplayOn_10();
  public void GlobalWarningDisplayOn()
    { GlobalWarningDisplayOn_10(); }

  private native void GlobalWarningDisplayOff_11();
  public void GlobalWarningDisplayOff()
    { GlobalWarningDisplayOff_11(); }

  private native int GetGlobalWarningDisplay_12();
  public int GetGlobalWarningDisplay()
    { return GetGlobalWarningDisplay_12(); }

  private native void RemoveObserver_13(int id0);
  public void RemoveObserver(int id0)
    { RemoveObserver_13(id0); }

  private native void RemoveObservers_14(int id0);
  public void RemoveObservers(int id0)
    { RemoveObservers_14(id0); }

  private native void RemoveObservers_15(String id0);
  public void RemoveObservers(String id0)
    { RemoveObservers_15(id0); }

  private native void RemoveAllObservers_16();
  public void RemoveAllObservers()
    { RemoveAllObservers_16(); }

  private native int HasObserver_17(int id0);
  public int HasObserver(int id0)
    { return HasObserver_17(id0); }

  private native int HasObserver_18(String id0);
  public int HasObserver(String id0)
    { return HasObserver_18(id0); }

  private native int InvokeEvent_19(int id0);
  public int InvokeEvent(int id0)
    { return InvokeEvent_19(id0); }

  private native int InvokeEvent_20(String id0);
  public int InvokeEvent(String id0)
    { return InvokeEvent_20(id0); }

  public vtkObject() { super(); }

  public vtkObject(long id) { super(id); }
  public native long   VTKInit();
  public native int AddObserver(String id0, Object id1, String id2);

}
